@@ -103,7 +103,7 @@ has y_offset =>
 	required	=> 0,
 );
 
-our $VERSION = '1.01';
+our $VERSION = '1.03';
 
 # ------------------------------------------------
 
@@ -310,7 +310,8 @@ sub grid
 
 sub image_link
 {
-	my($self, %options) = @_;
+	my($self, %options)	= @_;
+	my($image_id)		= "image_$options{x}_$options{y}"; # Try to make it unique.
 
 	$self -> svg -> anchor
 	(
@@ -320,13 +321,15 @@ sub image_link
 	) -> image
 	(
 		-href	=> $options{image},
-		id		=> "image_$options{x}_$options{y}", # Try to make it unique.
+		id		=> $image_id,
 		width	=> $self -> cell_width,
 		height	=> $self -> cell_height,
 		x		=> $self -> x_offset + $self -> cell_width * $options{x},
 		y		=> $self -> y_offset + $self -> cell_height * $options{y},
 	);
 
+	return $image_id;
+
 } # End of image_link.
 
 # ------------------------------------------------
@@ -348,6 +351,7 @@ sub rectangle_link
 {
 	my($self, %options) = @_;
 	my($defaults)		= $self -> _get_defaults(%options);
+	my($rectangle_id)	= "rectangle_$options{x}_$options{y}"; # Try to make it unique.
 
 	$self -> svg -> anchor
 	(
@@ -358,7 +362,7 @@ sub rectangle_link
 	(
 		fill			=> $$defaults{fill},
 		'fill-opacity'	=> $$defaults{fill_opacity} || 0.5, # We use 0.5 since the default is 0.
-		id				=> "rectangle_$options{x}_$options{y}", # Try to make it unique.
+		id				=> $rectangle_id,
 		stroke			=> $$defaults{stroke},
 		'stroke-width'	=> $$defaults{stroke_width},
 		width			=> $self -> cell_width,
@@ -367,6 +371,8 @@ sub rectangle_link
 		y				=> $self -> y_offset + $self -> cell_height * $options{y},
 	);
 
+	return $rectangle_id;
+
 } # End of rectangle_link.
 
 # ----------------------------------------------
@@ -400,6 +406,7 @@ sub text_link
 	my($self, %options)	= @_;
 	my($defaults)		= $self -> _get_defaults(%options);
 	my($half_font)		= int($$defaults{font_size} / 2);
+	my($text_id)		= "text_$options{x}_$options{y}"; # Try to make it unique.
 
 	$self -> svg -> anchor
 	(
@@ -408,7 +415,7 @@ sub text_link
 		target	=> $options{target} || '',
 	) -> text
 	(
-		id		=> "text_$options{x}_$options{y}", # Try to make it unique.
+		id		=> $text_id,
 		x		=> $self -> x_offset + $self -> cell_width * $options{x} + $$defaults{font_size} - $half_font,
 		y		=> $self -> y_offset + $self -> cell_height * $options{y} + $$defaults{font_size} + $half_font,
 		style	=>
@@ -423,6 +430,8 @@ sub text_link
 		}
 	) -> cdata($options{text});
 
+	return $text_id;
+
 } # End of text_link.
 
 # ------------------------------------------------
@@ -452,7 +461,7 @@ C<SVG::Grid> - Address SVG images using cells of $n1 x $n2 pixels
 
 This is scripts/synopsis.pl:
 
-	#!/use/bin/env perl
+	#!/usr/bin/env perl
 
 	use strict;
 	use warnings;
@@ -1047,7 +1056,7 @@ Australian copyright (c) 2016, Ron Savage.
 
 	All Programs of mine are 'OSI Certified Open Source Software';
 	you can redistribute them and/or modify them under the terms of
-	The Artistic License 2.0, a copy of which is available at:
-	http://opensource.org/licenses/alphabetical.
+	The Perl License, a copy of which is available at:
+	http://dev.perl.org/licenses/
 
 =cut
